@@ -17,10 +17,10 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.1.4'
+    version = '1.0.5'
     description = 'Send project error counts to DingDing .'
     resource_links = [
-        ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
+        ('Source', 'https://github.com/cench/sentry-10-dingding'),
         ('Bug Tracker', 'https://github.com/dreamerldq/sentry-dingding-format/issues'),
         ('README', 'https://github.com/dreamerldq/sentry-dingding-format/blob/master/README.md'),
     ]
@@ -40,31 +40,16 @@ class DingDingPlugin(NotificationPlugin):
     def notify_users(self, group, event, *args, **kwargs):
         self.post_process(group, event, *args, **kwargs)
 
-    def getGroupCount(self, groupId):
-        headers={
-            "Authorization": 'Bearer {token}'.format(token='4723370af03c4c95bc3bb0570fef1da3c5a2277477544571b827daceccbc3276')    
-        }
-        url = 'http://localhost:9000/api/0/issues/{groupId}/'.format(groupId=groupId )
-        r = requests.get(url,headers=headers).json()
-        return r["count"]
-
     def post_process(self, group, event, *args, **kwargs):
         """
         Process error.
         """
-
         if not self.is_configured(group.project):
             return
 
         if group.is_ignored():
             return
 
-        count = self.getGroupCount(group.id)
-
-        # if(int(count)>=2):
-        #     return
-        
-
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = u'【%s】的项目异常' % event.project.slug
@@ -73,19 +58,23 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > 责任人:{name} \n\n > UID:{uid} \n\n > Count:{count} \n\n > GROUPID:{groupId} \n\n >  {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > {device} \n\n > {uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
-                    name=event.get_tag('name'),
-                    count=count,
-                    groupId=group.id,
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
+            },
+            "at": {
+                "isAtALL": event.get_tag('errorLevel')=="P0"
             }
         }
+
+        if event.get_tag('environment')!='build':
+            return
+
         requests.post(
             url=send_url,
             headers={"Content-Type": "application/json"},
